@@ -31,6 +31,7 @@ def csvCleaner(csv_folder, csv_folder_cleaned):
 
     for i in range(len(fileList)):
         csv_cleaning(csv_folder + "\\" + fileList[i], csv_folder_cleaned)
+        print(fileList[i] + " is cleaned")
 
 def commonPreprocess(dataframe):
     # brand명 기준으로 이후 6글자 추출
@@ -51,9 +52,20 @@ def csvImporter(csv_folder, csv_folder_cleaned, db_table_name):
         dataframe.columns = column_name
         dataframe.insert(0, "file_name", fileList[i][:-4], True)
 
-        commonPreprocess(dataframe)
+        # commonPreprocess(dataframe)
         stackTodb(dataframe, db_table_name)
 
+def commonPreprocess(dataframe):
+    # brand명 기준으로 이후 6글자 추출
+    dataframe['brand'] = dataframe['brand'].str.lower()
+    dataframe['title'] = dataframe['title'].str.lower()
+    try:
+        dataframe['product_name_cut'] = dataframe.apply(lambda x: x['brand'] + ' ' + ' '.join(x['title'].split(x['brand'])[1].split()[:5]) if x['brand'] in x['title'] else '', axis=1)
+    except Exception:
+        pass
+
+    return dataframe
+
 def keywordPool(csv):
     pool = pd.read_csv(csv, sep=',', engine='c', encoding='latin-1')
     column = ["brand", "string", "product_name"]
@@ -76,7 +88,7 @@ def titleSummaryMaker(csv):
 
     return pool[['title_summary_temp', 'title_summary']]
 
-def csvImporter_NEW(db_table_name, csv_folder, csv_folder_cleaned, keyword_pool):
+def csvImporter_NEW(csv_folder, csv_folder_cleaned, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
     
     # csv 줄밀림 정제
@@ -158,8 +170,11 @@ def csvImporter_NEW(db_table_name, csv_folder, csv_folder_cleaned, keyword_pool)
             stackTodb(final_df, db_table_name)
 
 # if __name__ == "__main__":
-#     db_table_name = 'tb_stackline_dataset'
+# #     db_table_name = 'tb_stackline_dataset'
 #     csv_folder = "csvFolder"
 #     csv_folder_cleaned = "csvFolder_cleaned"
+#     keyword_pool = "csvimporteract\\tablet_phone_pool.csv"
      
-#     csvImporter(csv_folder, csv_folder_cleaned, db_table_name)
\ No newline at end of file
+# #     csvImporter(csv_folder, csv_folder_cleaned, db_table_name)
+
+#     csvImporter_NEW(csv_folder, csv_folder_cleaned, keyword_pool)
\ No newline at end of file
